@@ -75,10 +75,15 @@ def list_tasks():
     else:
         for task_name in _ordered_task_keys:
             task = _all_tasks[task_name]
+            shortdoc = task.__doc__
+            if not shortdoc:
+                shortdoc = "(no documentation)"
+            if "\n" in shortdoc:
+                shortdoc = shortdoc.split("\n")[0] + "..."
             format_string = "%%(name)-%ss # %%(optional_default_doc)s%%(doc)s" % max([len(name)+1 for name in _all_tasks.keys()])
             print format_string % dict(
                 name = task.__name__,
-                doc = task.__doc__,
+                doc = shortdoc,
                 optional_default_doc = {_default_task_name: "(default) "}.get(task_name, ""),
             )
     print
